:mod:`data` Package
===================


:mod:`data.featureset` Module
-----------------------------

.. automodule:: skll.data.featureset
    :members:
    :show-inheritance:

:mod:`data.readers` Module
--------------------------

.. automodule:: skll.data.readers
    :members:
    :show-inheritance:

:mod:`data.writers` Module
--------------------------

.. automodule:: skll.data.writers
    :members:
    :show-inheritance:
